#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules
#include "display.h"
#include "psocgpioint.h"

BYTE flag1=0;
BYTE flag2=0;
BYTE flag3=0;
BYTE flag4=0;
BYTE flag5=0;
BYTE flag6=0;
BYTE flag7=0;
BYTE flag8=0;
BYTE flag9=0;


//-----------------------------------------------------------------------------
//
//  Function:    display_init
//
//  Description: initialize the display subsystem
//                
//  Inputs:      Void
//
//  Returns:     Void
//
//-----------------------------------------------------------------------------
void display_init(void)
{
    display_clear_LEDs();
}

//-----------------------------------------------------------------------------
//
//  Function:    display_clear_LEDs
//
//  Description: Turn off all the LEDs
//                
//  Inputs:      Void
//
//  Returns:     Void
//
//-----------------------------------------------------------------------------
void display_clear_LEDs(void)
{
    LED_0_Switch(0);
	LED_1_Switch(0);
	LED_2_Switch(0);
	LED_3_Switch(0);
	LED_4_Switch(0);
	LED_5_Switch(0);
	LED_6_Switch(0);
	LED_7_Switch(0);
	LED_8_Switch(0);
}

//-----------------------------------------------------------------------------
//
//  Function:    display_update_LEDs
//
//  Description: This will turn on or off LEDs, depending on the button/slider
//   			 sensor state.
//                
//  Inputs:      BYTE sensor_state
//
//  Returns:     Void
//
//-----------------------------------------------------------------------------
//void display_update_LEDs(BYTE sensor_state)
//{
//    
//	LED_0_Switch( (sensor_state & 0x01) );
//	LED_1_Switch( (sensor_state & 0x02) );
//	LED_2_Switch( (sensor_state & 0x04) );
//	LED_3_Switch( (sensor_state & 0x08) );
//	LED_4_Switch( (sensor_state & 0x10) );
//}
void display_update_LEDs(BYTE sensor_state)
{
	if ( (sensor_state & 0x01) && flag1 ==0)
		{	
			flag1=1;
			LED_0_Invert();
		}
	else if (!CSA_EMC_bIsAnySensorActive())
		{	
			flag1=0;
		
		}
	if ( (sensor_state & 0x02) &&flag2 == 0 )
		{	
			flag2=1;
			LED_1_Invert();
		}
	else if (!CSA_EMC_bIsAnySensorActive())
		{	
			flag2=0;
		}
	if ( (sensor_state & 0x04) && flag3 == 0)
		{	
			flag3=1;
			LED_2_Invert();
		}
	else if (!CSA_EMC_bIsAnySensorActive())
		{	
			flag3=0;
		}
	if ( (sensor_state & 0x08) && flag4 == 0)
		{	
			flag4=1;
			LED_3_Invert();
		}
	else if (!CSA_EMC_bIsAnySensorActive())
		{	
			flag4=0;
		}
	if ( (sensor_state & 0x10) && flag5 == 0)
	    {
			flag5=1;
			LED_4_Invert();
		}
    else if (!CSA_EMC_bIsAnySensorActive())
		{	
			flag5=0;
		}
	if (  (sensor_state & 0x20) && flag6 == 0)
		{
			flag6=1;
			LED_5_Invert();
	  	}
	else if (!CSA_EMC_bIsAnySensorActive())
	  	{	
			flag6=0;
	  	}
	if (  (sensor_state & 0x40) && flag7== 0)
	  	{
			flag7=1;
			LED_6_Invert();
	  	}
	else if (!CSA_EMC_bIsAnySensorActive())
	  	{	
			flag7=0;
	  	}
	if (  (sensor_state & 0x80) && flag8 == 0)
		{
			flag8=1;
			LED_7_Invert();
	  	}
	else if (!CSA_EMC_bIsAnySensorActive())
	  	{	
			flag8=0;
	  	}
	if (  (sensor_state & 0x100) && flag9 == 0)
		{
			flag9=1;
			LED_8_Invert();
		}
	else if (!CSA_EMC_bIsAnySensorActive())
		{	
			flag9=0;
		}
  }


//-----------------------------------------------------------------------------
//
//  Function:    display_sensor_state
//
//  Description: Sets up the slider state, if a finger is present. And updates
//               the LEDs depending on the state .
//                
//  Inputs:      BYTE slider_pos - Value from 0 - 4 depending on what position
//				 the finger is on the slider.  0xFF if finger no finger present.
//
//               BYTE button_state - Current on/off state of the 5 buttons.
//
//  Returns:     Void
//
//-----------------------------------------------------------------------------
void display_sensor_state(BYTE slider_pos, BYTE button_state)
{
	BYTE i;
	BYTE slider_state = 0;
	
	if (slider_pos != 0xFF) // check for slider activity 
    {
        display_clear_LEDs(); // clear old slider data
        
        // Update slider state (slider has a resolution of 5, because there are
        //    5 LEDs) by shifting and setting to 1 or leave 0 depending on 
        //    position 
		for (i = 0; i < 5; i++)
		{
			slider_state <<= 1; // shift slider_state to correctly set LEDs
			if (slider_pos == 4 - i)
			{
				slider_state++; // add one to the end
			}
		}
		// display both slider and button states
		display_update_LEDs(slider_state | button_state); 
    }
    else
    {
    	// display button state
        display_update_LEDs(button_state);
    }
}
